@@ -31,7 +31,7 @@ use POE::Declare ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.15';
+	$VERSION = '0.16';
 }
 
 # Inside-out storage of internal values
@@ -615,46 +615,6 @@ sub delay_adjust {
 
 
 
-#####################################################################
-# Timeout Support
-
-=pod
-
-=head2 timeout_start 
-
-  # Declare a timer event
-  sub event : Timeout(30) {
-    # Do something
-  }
-  
-  # Start a 5 minute timeout
-  $object->timeout_start(300);
-
-The C<timeout_start> method starts an alarm timer for a named C<Timeout>
-event.
-
-=cut
-
-sub timeout_start {
-	my $self = shift;
-	my $name = shift;
-
-	# Check params
-	my $attr = $self->meta->attr($name);
-	unless ( $attr and $attr->isa('POE::Declare::Meta::Timeout') ) {
-		Carp::croak("Slot '$name' does not exist or not a timeout");
-	}
-	my $delay = shift or $attr->delay;
-
-	# Kick off the POE timer
-	my $id = $self->delay_set( $name => $delay );
-	
-}
-
-
-
-
-
 #####################################################################
 # message Support
 
